@@ -281,7 +281,7 @@ ml_lvm <- function(
                                   ),
                                   sample = sampleStats,computed = FALSE, 
                                   equal = equal,
-                                  optimizer =  "nlminb", estimator = estimator, distribution = "Gaussian",
+                                  optimizer =  defaultoptimizer(), estimator = estimator, distribution = "Gaussian",
                                   identification=identification, verbose=verbose)
   
   # Number of groups:
